#!/bin/sh
#------------------------------------------------------------------------------
# /tmp/install.sh - installation file for chroot services on EIS/FAIR
#
# Copyright (c) 2008-2015 The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2008-07-07  jed
# Last Update:  $Id: install.sh 37951 2015-05-17 08:45:41Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version..
#------------------------------------------------------------------------------

# include eislib
. /var/install/include/eislib
. /var/install/include/check-eisfair-version
. /var/install/include/jedlib

module_name='chroot'

installfile=/var/run/${module_name}.install

mecho --info "running install.sh ..."

# update shared library file
update_jedlib ${module_name}

# set platform specific parameters
case ${EISFAIR_SYSTEM} in
    eisfair-1)
        # eisfair-1
        chroot_configpath=/var/chroot
        ;;
    *)
        # default to eisfair-2
        chroot_configpath=/data/packages/chroot
        ;;
esac

# menu
mecho "adding menu ..."
/var/install/bin/add-menu --menu "setup.services.menu" "setup.services.${module_name}.menu" "Chroot Service"

# check group
group='chroot'
gid=''

grep -q "^${group}:" /etc/group

if [ $? -ne 0 ]
then
    mecho "adding group '${group}' ..."
    /var/install/bin/add-group ${group} ${gid}
fi

# create directory
if [ ! -d ${chroot_configpath} ]
then
    mkdir -p ${chroot_configpath}
fi

# extract intial content
cd ${chroot_configpath}
tar xf /tmp/var-${module_name}-1.tar
rm -f /tmp/var-${module_name}-?.tar

chown -R root ${chroot_configpath}
chgrp -R root ${chroot_configpath}

if [ -f /etc/chroot-save-pathinfo -a ! -f ${chroot_configpath}/chroot-save-pathinfo ]
then
    mv /etc/chroot-save-pathinfo ${chroot_configpath}/
fi

if [ -f /etc/chroot-save-userinfo -a ! -f ${chroot_configpath}/chroot-save-userinfo ]
then
    mv /etc/chroot-save-userinfo ${chroot_configpath}/
fi

# move old files to backup directory and create backup
/var/install/bin/backup-file --quiet ${module_name}

# install/update package configuration file
update=false
if install_config ${module_name}
then
    update=true
fi

if [ "${update}" = "true" ]
then
    # updated installation
    /var/install/config.d/${module_name}.sh
    if [ -f /etc/init.d/${module_name} ]
    then
        /etc/init.d/${module_name} restart
    fi
else
    # new installation
    /var/install/bin/edit --apply "${module_name}" "Edit ${module_name} services configuration"
fi

exit 0
