#!/bin/sh
#------------------------------------------------------------------------------
# /tmp/preinstall.sh - pre installation file for chroot services on EIS/FAIR
#
# Copyright (c) 2008-2015 The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2008-07-07  jed
# Last Update:  $Id: preinstall.sh 37951 2015-05-17 08:45:41Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version..
#------------------------------------------------------------------------------

# include eislib etc.
. /var/install/include/eislib

module_name='chroot'

# file names
configfile=/etc/config.d/${module_name}
installfile=/var/run/${module_name}.install
deinstallfile=/var/install/deinstall/${module_name}
packagefile=/var/install/packages/${module_name}

mecho --info "running preinstall.sh ..."

# check base version
if [ -f ${packagefile} ]
then
    base_version="`grep "<require-package>base " ${packagefile} | sed 's#^.*<require-package>base *\(.*\) *</require-.*$#\1#'`"
else
    base_version='2.6.3'
fi
installed_version=`/var/install/bin/check-version base ${base_version}`

case ${installed_version} in
    not-installed|new ) # wrong version
        mecho --error "required base package v${base_version} or newer not installed - installation aborted."
        /var/install/bin/anykey
        exit 1
        ;;
    * ) # installed / old
        ;;
esac

# backup existing file
if [ -f "${configfile}" ]
then
    mecho "saving previous configuration file to ${installfile} ..."
    cp ${configfile} ${installfile}
fi

# deinstall old software
mecho "deinstalling previously installed software ..."
/var/install/bin/del-package -p ${module_name} --update

exit 0
