#!/bin/sh
#----------------------------------------------------------------------------
# /var/install/config.d/chroot-update.sh - update or generate new configuration
#
# Copyright (c) 2008-2015 The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2008-07-06  jed
# Last Updated: $Id: chroot-update.sh 37959 2015-05-17 17:08:49Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

# include eislib
. /var/install/include/eislib
. /var/install/include/configlib

#------------------------------------------------------------------------------
# function: variable is set
#
# input:  $1 - variable name
# return:  0 - variable set
#          1 - variable not set
#------------------------------------------------------------------------------
variable_set ()
{
    eval _var1=\$"${1}"
    eval _var2=\$"{${1}+EMPTY}"

    if [ -z "${_var1}" ]
    then
        if [ "${_var2}" = "EMPTY" ]
        then
            # variable is empty, but set
            ret=0
        else
            # variable is not set
            ret=1
        fi
    else
        # variable has a value
        ret=0
    fi

    return ${ret}
}

#------------------------------------------------------------------------------
# print variable only if it has been set
# $1 - variable name
# $2 - comment
#------------------------------------------------------------------------------
printsetvar ()
{
    if variable_set "${1}"
    then
        printvar "${1}" "${2}"
    fi
}

#------------------------------------------------------------------------------
# rename variables
#------------------------------------------------------------------------------
rename_variables ()
{
    renamed=0
    mecho "renaming parameter(s) ..."

    # v1.14.7
  # if [ ! -z "`grep ^USE_NETDATE_TIMESERVER $source_conf`" ]
  # then
  #     echo "- USE_NETDATE_TIMESERVER -> NETDATE_TIMESERVER_NBR"
  #     NETDATE_TIMESERVER_NBR="$USE_NETDATE_TIMESERVER"
  #     renamed=1
  # fi

    if [ ${renamed} -eq 1 ]
    then
        mecho --info "... read documentation for renamed parameter(s)!"
        anykey
    fi
}

#------------------------------------------------------------------------------
# modify variables
#------------------------------------------------------------------------------
modify_variables ()
{
    modified=0
    mecho "modifying parameter(s) ..."

    if [ "${CHROOT_N}" = "0" ]
    then
        echo "- CHROOT_N, '0' -> '1'"
        CHROOT_N=1
        modified=1
    fi

    if [ ${modified} -eq 1 ]
    then
        mecho --info "... read documentation for modified parameter(s)!"
        anykey
    fi
}

#------------------------------------------------------------------------------
# add variables
#------------------------------------------------------------------------------
add_variables ()
{
    added=0
    mecho "adding new parameter(s) ..."

    if [ -z "`grep ^CHROOT_DEFAULT_ENABLE_SSH_APPS ${source_conf}`" ]
    then
        echo "- CHROOT_DEFAULT_ENABLE_SSH_APPS='no'"
        CHROOT_DEFAULT_ENABLE_SSH_APPS='no'
        added=1
    fi

    if [ -z "`grep ^CHROOT_DEFAULT_ENABLE_RSYNC_APPS ${source_conf}`" ]
    then
        echo "- CHROOT_DEFAULT_ENABLE_RSYNC_APPS='no'"
        CHROOT_DEFAULT_ENABLE_RSYNC_APPS='no'
        added=1
    fi

    # v1.1.0
    if [ ${CHROOT_N} -eq 0 ]
    then
        imax=1
    else
        imax=${CHROOT_N}
    fi

    idx=1
    while [ ${idx} -le ${imax} ]
    do
        eval lock_user='$CHROOT_'${idx}'_LOCK_USER'

        if [ -z "`grep ^CHROOT_${idx}_LOCK_USER ${source_conf}`" ]
        then
            mecho "- CHROOT_${idx}_LOCK_USER='yes'"
            eval "CHROOT_${idx}_LOCK_USER='yes'"
            added=1
        fi

        idx=`expr ${idx} + 1`
    done

    if [ ${added} -eq 1 ]
    then
        mecho --info "... read documentation for new parameter(s)!"
        anykey
    fi
}

#------------------------------------------------------------------------------
# delete variables
#------------------------------------------------------------------------------
delete_variables ()
{
    deleted=0
    mecho "deleting old parameters ..."

  # if [ ! -z "`grep ^NETDATE_TIMESERVER_NBR $source_conf`" ]
  # then
  #     echo "- NETDATE_TIMESERVER_NBR"

  #     idx=1
  #     exitflag=0
  #     while [ $exitflag -eq 0 ]
  #     do
  #         if [ $idx -ne $NETDATE_TIMESERVER_NBR ]
  #         then
  #             if [ ! -z "`grep "^NETDATE_TIMESERVER_${idx}" $source_conf`" ]
  #             then
  #                 echo "- NETDATE_TIMESERVER_${idx}"
  #                 deleted=1
  #             else
  #                 # exit loop
  #                 exitflag=1
  #             fi
  #         fi

  #         if [ $idx -eq  20 ]
  #         then
  #             # exit loop
  #             exitflag=1
  #         fi

  #         idx=`expr ${idx} + 1`
  #     done
  # fi

    if [ ${deleted} -eq 1 ]
    then
        anykey
    fi
}

#------------------------------------------------------------------------------
# create new configuration
#------------------------------------------------------------------------------
create_config ()
{
    mecho "updating/creating configuration ..."

    {
        #------------------------------------------------------------------------------
        printgpl -conf "chroot" "2015-05-17" "jed"
        #------------------------------------------------------------------------------

        if [ "${CHROOT_DO_DEBUG}" = "yes" -o "${CHROOT_DO_DEBUG}" = "no" ]
        then
            # debug active
            printvar "CHROOT_DO_DEBUG" "debug mode: yes or no"
            echo
        else
            # debug parameter exists but not active
            if [ -n "`grep CHROOT_DO_DEBUG ${source_conf}`" ]
            then
                echo "# CHROOT_DO_DEBUG='yes'                   # debug mode: yes or no"
                echo
            fi
        fi

        #------------------------------------------------------------------------------
        printgroup "general settings"
        #------------------------------------------------------------------------------
        printvar "START_CHROOT"                     "start chroot package: yes or no"
        echo
        printvar "CHROOT_DEFAULT_JAILPATH"          "default chroot jail directory"
        printvar "CHROOT_DEFAULT_ENABLE_SSH_APPS"   "default: copy ssh, scp etc."
        printvar "CHROOT_DEFAULT_ENABLE_RSYNC_APPS" "default: copy rsync etc."

        #------------------------------------------------------------------------------
        printgroup "chroot accounts"
        #------------------------------------------------------------------------------
        printvar "CHROOT_N"                   "number of chroot accounts"

        if [ ${CHROOT_N} -eq 0 ]
        then
            imax=1
        else
            imax=${CHROOT_N}
        fi

        idx=1
        while [ ${idx} -le ${imax} ]
        do
            printvar "CHROOT_${idx}_ACTIVE"    "${idx}. activate: yes or no"
            printvar "CHROOT_${idx}_COMMENT"   "   comment"
            printvar "CHROOT_${idx}_USER"      "   username"
            printvar "CHROOT_${idx}_JAILPATH"  "   individual chroot jail directory"
            printvar "CHROOT_${idx}_LOCK_USER" "   lock user in chroot jail"

            printsetvar "CHROOT_${idx}_ENABLE_SSH_APPS"   "   individual copy ssh, scp etc."
            printsetvar "CHROOT_${idx}_ENABLE_RSYNC_APPS" "   individual copy rsync etc."

            idx=`expr ${idx} + 1`
        done

        #------------------------------------------------------------------------------
        printend
        #------------------------------------------------------------------------------
    } > ${generate_conf}

    anykey
}

#==============================================================================
# main
#==============================================================================

#testroot=/soft/jedchroot
 testroot=''

chrootfile=${testroot}/etc/config.d/chroot
installfile=/var/run/chroot.install

# setting defaults
source_conf=${installfile}
generate_conf=${chrootfile}

goflag=0

case "$1" in
    update)
        goflag=1
        ;;
    test)
        source_conf=${chrootfile}
      # source_conf=${chrootfile}.new

        generate_conf=${testroot}/etc/config.d/mk_chroot.test
        goflag=1
        ;;
    *)
        mecho
        mecho "Use one of the following options:"
        mecho
        mecho "  chroot-update.sh [update] - the file ${chrootfile}.import will be read, the configuration will"
        mecho "                              be checked and an updated mail configuration file will be written."
        mecho
        goflag=0
esac

if [ ${goflag} -eq 1 ]
then
    if [ -f ${source_conf} ]
    then
        # previous configuration file exists
        mecho --info "previous configuration found ..."
        . ${source_conf}

        rename_variables
        modify_variables
        add_variables
        delete_variables

        create_config
    else
        mecho --error "no configuration ${source_conf} found - exiting."
        anykey
    fi
fi

#==============================================================================
# end
#==============================================================================
